#!/bin/bash

curl ${CURL_OPTIONS:-} \
	--data-urlencode "action=hangup" \
	--data-urlencode "innum=$1" \
	--data-urlencode "did=$2" \
	--data-urlencode "exten=$3" \
	--data-urlencode "anwstime=$4" \
	--data-urlencode "state=$5" \
	--data-urlencode "recfile=$6" \
	--data-urlencode "uniq=$7" \
	--data-urlencode "accountcode=$8" \
	"https://asterisk-connect.zruchna.io/?ats=$klient"
